==> sdd.edireader-0.1.10-sources.jar: ar/com/sdd/edireader/model/EdifactItem.java <==
package ar.com.sdd.edireader.model;

import java.io.Serializable;

public class EdifactItem implements Serializable {

    private Long id;
    private String itemNumber;
    private String description;
    private int quantity;
    private int boxQuantity;
    private int totalQuantity;
    private double price;
    private double total;
    private double discountValue1;
    private double discountValue2;
    private double promotion;
    private double netAmountPerItem;
    private String status;
    private double computedWeight;

    public EdifactItem() {

    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    public double getTotal() {
        return total;
    }

    public void setTotal(double total) {
        this.total = total;
    }

    public double getDiscountValue1() {
        return discountValue1;
    }

    public void setDiscountValue1(double discountValue1) {
        this.discountValue1 = discountValue1;
    }

    public double getDiscountValue2() {
        return discountValue2;
    }

    public void setDiscountValue2(double discountValue2) {
        this.discountValue2 = discountValue2;
    }

    public double getPromotion() {
        return promotion;
    }

    public void setPromotion(double promotion) {
        this.promotion = promotion;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getItemNumber() {
        return itemNumber;
    }

    public void setItemNumber(String itemNumber) {
        this.itemNumber = itemNumber;
    }

    public int getBoxQuantity() {
        return boxQuantity;
    }

    public void setBoxQuantity(int boxQuantity) {
        this.boxQuantity = boxQuantity;
    }

    public int getTotalQuantity() {
        return totalQuantity;
    }

    public void setTotalQuantity(int totalQuantity) {
        this.totalQuantity = totalQuantity;
    }

    public double getNetAmountPerItem() {
        return netAmountPerItem;
    }

    public void setNetAmountPerItem(double netAmountPerItem) {
        this.netAmountPerItem = netAmountPerItem;
    }

    public double getComputedWeight() {
        return computedWeight;
    }

    public void setComputedWeight(double computedWeight) {
        this.computedWeight = computedWeight;
    }



    @Override
    public String toString() {
        return "EdifactItem ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((itemNumber != null) ? "itemNumber=" + itemNumber + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + "quantity=" + quantity + ", "
                + "boxQuantity=" + boxQuantity + ", "
                + "totalQuantity=" + totalQuantity + ", "
                + "price=" + price + ", "
                + "total=" + total + ", "
                + "discountValue1=" + discountValue1 + ", "
                + "discountValue2=" + discountValue2 + ", "
                + "promotion=" + promotion + ", "
                + "netAmountPerItem=" + netAmountPerItem + ", "
                + ((status != null) ? "status=" + status + ", " : "")
                + "computedWeight=" + computedWeight
                + "]";
    }
}

==> sdd.edireader-1.0.2-sources.jar: ar/com/sdd/edireader/model/EdifactItem.java <==
package ar.com.sdd.edireader.model;

import java.io.Serializable;

/**
 * EdifactItem es um pojo que representa los itens de uma factura */

public class EdifactItem implements Serializable {

    private Long id;
    private String itemNumber;//Numero identificador del producto
    private String description;
    private int quantity;
    private int boxQuantity;
    private int totalQuantity;
    private double price;
    private double total;
    private double discountValue1;
    private double discountValue2;
    private double promotion;
    private double netAmountPerItem;//Valor unitario de cada producto
    private String status;
    private double computedWeight; //KG neto

    public EdifactItem() {

    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    public double getTotal() {
        return total;
    }

    public void setTotal(double total) {
        this.total = total;
    }

    public double getDiscountValue1() {
        return discountValue1;
    }

    public void setDiscountValue1(double discountValue1) {
        this.discountValue1 = discountValue1;
    }

    public double getDiscountValue2() {
        return discountValue2;
    }

    public void setDiscountValue2(double discountValue2) {
        this.discountValue2 = discountValue2;
    }

    public double getPromotion() {
        return promotion;
    }

    public void setPromotion(double promotion) {
        this.promotion = promotion;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getItemNumber() {
        return itemNumber;
    }

    public void setItemNumber(String itemNumber) {
        this.itemNumber = itemNumber;
    }

    public int getBoxQuantity() {
        return boxQuantity;
    }

    public void setBoxQuantity(int boxQuantity) {
        this.boxQuantity = boxQuantity;
    }

    public int getTotalQuantity() {
        return totalQuantity;
    }

    public void setTotalQuantity(int totalQuantity) {
        this.totalQuantity = totalQuantity;
    }

    public double getNetAmountPerItem() {
        return netAmountPerItem;
    }

    public void setNetAmountPerItem(double netAmountPerItem) {
        this.netAmountPerItem = netAmountPerItem;
    }

    public double getComputedWeight() {
        return computedWeight;
    }

    public void setComputedWeight(double computedWeight) {
        this.computedWeight = computedWeight;
    }



    @Override
    public String toString() {
        return "EdifactItem ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((itemNumber != null) ? "itemNumber=" + itemNumber + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + "quantity=" + quantity + ", "
                + "boxQuantity=" + boxQuantity + ", "
                + "totalQuantity=" + totalQuantity + ", "
                + "price=" + price + ", "
                + "total=" + total + ", "
                + "discountValue1=" + discountValue1 + ", "
                + "discountValue2=" + discountValue2 + ", "
                + "promotion=" + promotion + ", "
                + "netAmountPerItem=" + netAmountPerItem + ", "
                + ((status != null) ? "status=" + status + ", " : "")
                + "computedWeight=" + computedWeight
                + "]";
    }
}
